/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ApplicationOptionalClaimsAConfig extends cdktf.TerraformMetaArguments {
    /**
    * The resource ID of the application to which these optional claims belong
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#application_id ApplicationOptionalClaimsA#application_id}
    */
    readonly applicationId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#id ApplicationOptionalClaimsA#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * access_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#access_token ApplicationOptionalClaimsA#access_token}
    */
    readonly accessToken?: ApplicationOptionalClaimsAccessTokenA[] | cdktf.IResolvable;
    /**
    * id_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#id_token ApplicationOptionalClaimsA#id_token}
    */
    readonly idToken?: ApplicationOptionalClaimsIdTokenA[] | cdktf.IResolvable;
    /**
    * saml2_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#saml2_token ApplicationOptionalClaimsA#saml2_token}
    */
    readonly saml2Token?: ApplicationOptionalClaimsSaml2TokenA[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#timeouts ApplicationOptionalClaimsA#timeouts}
    */
    readonly timeouts?: ApplicationOptionalClaimsTimeouts;
}
export interface ApplicationOptionalClaimsAccessTokenA {
    /**
    * List of additional properties of the claim. If a property exists in this list, it modifies the behaviour of the optional claim
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#additional_properties ApplicationOptionalClaimsA#additional_properties}
    */
    readonly additionalProperties?: string[];
    /**
    * Whether the claim specified by the client is necessary to ensure a smooth authorization experience
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#essential ApplicationOptionalClaimsA#essential}
    */
    readonly essential?: boolean | cdktf.IResolvable;
    /**
    * The name of the optional claim
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#name ApplicationOptionalClaimsA#name}
    */
    readonly name: string;
    /**
    * The source of the claim. If `source` is absent, the claim is a predefined optional claim. If `source` is `user`, the value of `name` is the extension property from the user object
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#source ApplicationOptionalClaimsA#source}
    */
    readonly source?: string;
}
export declare function applicationOptionalClaimsAccessTokenAToTerraform(struct?: ApplicationOptionalClaimsAccessTokenA | cdktf.IResolvable): any;
export declare function applicationOptionalClaimsAccessTokenAToHclTerraform(struct?: ApplicationOptionalClaimsAccessTokenA | cdktf.IResolvable): any;
export declare class ApplicationOptionalClaimsAccessTokenAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApplicationOptionalClaimsAccessTokenA | cdktf.IResolvable | undefined;
    set internalValue(value: ApplicationOptionalClaimsAccessTokenA | cdktf.IResolvable | undefined);
    private _additionalProperties?;
    get additionalProperties(): string[];
    set additionalProperties(value: string[]);
    resetAdditionalProperties(): void;
    get additionalPropertiesInput(): string[] | undefined;
    private _essential?;
    get essential(): boolean | cdktf.IResolvable;
    set essential(value: boolean | cdktf.IResolvable);
    resetEssential(): void;
    get essentialInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    resetSource(): void;
    get sourceInput(): string | undefined;
}
export declare class ApplicationOptionalClaimsAccessTokenAList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApplicationOptionalClaimsAccessTokenA[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApplicationOptionalClaimsAccessTokenAOutputReference;
}
export interface ApplicationOptionalClaimsIdTokenA {
    /**
    * List of additional properties of the claim. If a property exists in this list, it modifies the behaviour of the optional claim
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#additional_properties ApplicationOptionalClaimsA#additional_properties}
    */
    readonly additionalProperties?: string[];
    /**
    * Whether the claim specified by the client is necessary to ensure a smooth authorization experience
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#essential ApplicationOptionalClaimsA#essential}
    */
    readonly essential?: boolean | cdktf.IResolvable;
    /**
    * The name of the optional claim
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#name ApplicationOptionalClaimsA#name}
    */
    readonly name: string;
    /**
    * The source of the claim. If `source` is absent, the claim is a predefined optional claim. If `source` is `user`, the value of `name` is the extension property from the user object
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#source ApplicationOptionalClaimsA#source}
    */
    readonly source?: string;
}
export declare function applicationOptionalClaimsIdTokenAToTerraform(struct?: ApplicationOptionalClaimsIdTokenA | cdktf.IResolvable): any;
export declare function applicationOptionalClaimsIdTokenAToHclTerraform(struct?: ApplicationOptionalClaimsIdTokenA | cdktf.IResolvable): any;
export declare class ApplicationOptionalClaimsIdTokenAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApplicationOptionalClaimsIdTokenA | cdktf.IResolvable | undefined;
    set internalValue(value: ApplicationOptionalClaimsIdTokenA | cdktf.IResolvable | undefined);
    private _additionalProperties?;
    get additionalProperties(): string[];
    set additionalProperties(value: string[]);
    resetAdditionalProperties(): void;
    get additionalPropertiesInput(): string[] | undefined;
    private _essential?;
    get essential(): boolean | cdktf.IResolvable;
    set essential(value: boolean | cdktf.IResolvable);
    resetEssential(): void;
    get essentialInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    resetSource(): void;
    get sourceInput(): string | undefined;
}
export declare class ApplicationOptionalClaimsIdTokenAList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApplicationOptionalClaimsIdTokenA[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApplicationOptionalClaimsIdTokenAOutputReference;
}
export interface ApplicationOptionalClaimsSaml2TokenA {
    /**
    * List of additional properties of the claim. If a property exists in this list, it modifies the behaviour of the optional claim
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#additional_properties ApplicationOptionalClaimsA#additional_properties}
    */
    readonly additionalProperties?: string[];
    /**
    * Whether the claim specified by the client is necessary to ensure a smooth authorization experience
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#essential ApplicationOptionalClaimsA#essential}
    */
    readonly essential?: boolean | cdktf.IResolvable;
    /**
    * The name of the optional claim
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#name ApplicationOptionalClaimsA#name}
    */
    readonly name: string;
    /**
    * The source of the claim. If `source` is absent, the claim is a predefined optional claim. If `source` is `user`, the value of `name` is the extension property from the user object
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#source ApplicationOptionalClaimsA#source}
    */
    readonly source?: string;
}
export declare function applicationOptionalClaimsSaml2TokenAToTerraform(struct?: ApplicationOptionalClaimsSaml2TokenA | cdktf.IResolvable): any;
export declare function applicationOptionalClaimsSaml2TokenAToHclTerraform(struct?: ApplicationOptionalClaimsSaml2TokenA | cdktf.IResolvable): any;
export declare class ApplicationOptionalClaimsSaml2TokenAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApplicationOptionalClaimsSaml2TokenA | cdktf.IResolvable | undefined;
    set internalValue(value: ApplicationOptionalClaimsSaml2TokenA | cdktf.IResolvable | undefined);
    private _additionalProperties?;
    get additionalProperties(): string[];
    set additionalProperties(value: string[]);
    resetAdditionalProperties(): void;
    get additionalPropertiesInput(): string[] | undefined;
    private _essential?;
    get essential(): boolean | cdktf.IResolvable;
    set essential(value: boolean | cdktf.IResolvable);
    resetEssential(): void;
    get essentialInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    resetSource(): void;
    get sourceInput(): string | undefined;
}
export declare class ApplicationOptionalClaimsSaml2TokenAList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApplicationOptionalClaimsSaml2TokenA[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApplicationOptionalClaimsSaml2TokenAOutputReference;
}
export interface ApplicationOptionalClaimsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#create ApplicationOptionalClaimsA#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#delete ApplicationOptionalClaimsA#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#read ApplicationOptionalClaimsA#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#update ApplicationOptionalClaimsA#update}
    */
    readonly update?: string;
}
export declare function applicationOptionalClaimsTimeoutsToTerraform(struct?: ApplicationOptionalClaimsTimeouts | cdktf.IResolvable): any;
export declare function applicationOptionalClaimsTimeoutsToHclTerraform(struct?: ApplicationOptionalClaimsTimeouts | cdktf.IResolvable): any;
export declare class ApplicationOptionalClaimsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApplicationOptionalClaimsTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ApplicationOptionalClaimsTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims azuread_application_optional_claims}
*/
export declare class ApplicationOptionalClaimsA extends cdktf.TerraformResource {
    static readonly tfResourceType = "azuread_application_optional_claims";
    /**
    * Generates CDKTF code for importing a ApplicationOptionalClaimsA resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ApplicationOptionalClaimsA to import
    * @param importFromId The id of the existing ApplicationOptionalClaimsA that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ApplicationOptionalClaimsA to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/application_optional_claims azuread_application_optional_claims} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ApplicationOptionalClaimsAConfig
    */
    constructor(scope: Construct, id: string, config: ApplicationOptionalClaimsAConfig);
    private _applicationId?;
    get applicationId(): string;
    set applicationId(value: string);
    get applicationIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _accessToken;
    get accessToken(): ApplicationOptionalClaimsAccessTokenAList;
    putAccessToken(value: ApplicationOptionalClaimsAccessTokenA[] | cdktf.IResolvable): void;
    resetAccessToken(): void;
    get accessTokenInput(): cdktf.IResolvable | ApplicationOptionalClaimsAccessTokenA[] | undefined;
    private _idToken;
    get idToken(): ApplicationOptionalClaimsIdTokenAList;
    putIdToken(value: ApplicationOptionalClaimsIdTokenA[] | cdktf.IResolvable): void;
    resetIdToken(): void;
    get idTokenInput(): cdktf.IResolvable | ApplicationOptionalClaimsIdTokenA[] | undefined;
    private _saml2Token;
    get saml2Token(): ApplicationOptionalClaimsSaml2TokenAList;
    putSaml2Token(value: ApplicationOptionalClaimsSaml2TokenA[] | cdktf.IResolvable): void;
    resetSaml2Token(): void;
    get saml2TokenInput(): cdktf.IResolvable | ApplicationOptionalClaimsSaml2TokenA[] | undefined;
    private _timeouts;
    get timeouts(): ApplicationOptionalClaimsTimeoutsOutputReference;
    putTimeouts(value: ApplicationOptionalClaimsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ApplicationOptionalClaimsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
