/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface UserFlowAttributeConfig extends cdktf.TerraformMetaArguments {
    /**
    * The data type of the user flow attribute
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#data_type UserFlowAttribute#data_type}
    */
    readonly dataType: string;
    /**
    * The description of the user flow attribute that is shown to the user at the time of sign-up
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#description UserFlowAttribute#description}
    */
    readonly description: string;
    /**
    * The display name of the user flow attribute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#display_name UserFlowAttribute#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#id UserFlowAttribute#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#timeouts UserFlowAttribute#timeouts}
    */
    readonly timeouts?: UserFlowAttributeTimeouts;
}
export interface UserFlowAttributeTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#create UserFlowAttribute#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#delete UserFlowAttribute#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#read UserFlowAttribute#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#update UserFlowAttribute#update}
    */
    readonly update?: string;
}
export declare function userFlowAttributeTimeoutsToTerraform(struct?: UserFlowAttributeTimeouts | cdktf.IResolvable): any;
export declare function userFlowAttributeTimeoutsToHclTerraform(struct?: UserFlowAttributeTimeouts | cdktf.IResolvable): any;
export declare class UserFlowAttributeTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): UserFlowAttributeTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: UserFlowAttributeTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute azuread_user_flow_attribute}
*/
export declare class UserFlowAttribute extends cdktf.TerraformResource {
    static readonly tfResourceType = "azuread_user_flow_attribute";
    /**
    * Generates CDKTF code for importing a UserFlowAttribute resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the UserFlowAttribute to import
    * @param importFromId The id of the existing UserFlowAttribute that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the UserFlowAttribute to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azuread/3.1.0/docs/resources/user_flow_attribute azuread_user_flow_attribute} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options UserFlowAttributeConfig
    */
    constructor(scope: Construct, id: string, config: UserFlowAttributeConfig);
    get attributeType(): string;
    private _dataType?;
    get dataType(): string;
    set dataType(value: string);
    get dataTypeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _timeouts;
    get timeouts(): UserFlowAttributeTimeoutsOutputReference;
    putTimeouts(value: UserFlowAttributeTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | UserFlowAttributeTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
